Class: Project

Inherits:
Object
  • Object
show all
Defined in:
lib/almirah/project.rb

Overview

rubocop:disable Metrics/ClassLength,Style/Documentation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(configuration) ⇒ Project

Returns a new instance of Project.



16
17
18
19
20
21
22
23
24
# File 'lib/almirah/project.rb', line 16

def initialize(configuration)
  @configuration = configuration
  @project_data = ProjectData.new

  @index = nil
  @project = self
  FileUtils.remove_dir("#{@configuration.project_root_directory}/build", true)
  copy_resources
end

Instance Attribute Details

#configurationObject

Returns the value of attribute configuration.



14
15
16
# File 'lib/almirah/project.rb', line 14

def configuration
  @configuration
end

#indexObject

Returns the value of attribute index.



14
15
16
# File 'lib/almirah/project.rb', line 14

def index
  @index
end

#projectObject

Returns the value of attribute project.



14
15
16
# File 'lib/almirah/project.rb', line 14

def project
  @project
end

#project_dataObject

Returns the value of attribute project_data.



14
15
16
# File 'lib/almirah/project.rb', line 14

def project_data
  @project_data
end

Instance Method Details

#check_wrong_specification_referencedObject

rubocop:disable Metrics/AbcSize,Metrics/CyclomaticComplexity,Metrics/MethodLength,Metrics/PerceivedComplexity



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/almirah/project.rb', line 199

def check_wrong_specification_referenced # rubocop:disable Metrics/AbcSize,Metrics/CyclomaticComplexity,Metrics/MethodLength,Metrics/PerceivedComplexity
  available_specification_ids = {}

  @project_data.specifications.each do |s|
    available_specification_ids[s.id.to_s.downcase] = s
  end

  @project_data.specifications.each do |s| # rubocop:disable Style/CombinableLoops
    s.up_link_docs.each do |key, _value|
      next if available_specification_ids.key?(key)

      # now key points to the doc_id that does not exist
      wrong_doc_id = key
      # find the item that reference to it
      s.controlled_items.each do |item|
        next if item.up_link_ids.nil?

        item.up_link_ids.each do |up_link_id|
          next unless tmp = /^([a-zA-Z]+)-\d+/.match(up_link_id) # SRS

          if tmp[1].downcase == wrong_doc_id
            # we got it finally!
            s.wrong_links_hash[up_link_id.to_s] = item
          end
        end
      end
    end
  end
end

#copy_resourcesObject



26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/almirah/project.rb', line 26

def copy_resources
  # scripts
  gem_root = File.expand_path './../..', File.dirname(__FILE__)
  src_folder = "#{gem_root}/lib/almirah/templates/scripts"
  dst_folder = "#{@configuration.project_root_directory}/build/scripts"
  FileUtils.mkdir_p(dst_folder)
  FileUtils.copy_entry(src_folder, dst_folder)
  # css
  src_folder = "#{gem_root}/lib/almirah/templates/css"
  dst_folder = "#{@configuration.project_root_directory}/build/css"
  FileUtils.mkdir_p(dst_folder)
  FileUtils.copy_entry(src_folder, dst_folder)
end

#create_indexObject



266
267
268
# File 'lib/almirah/project.rb', line 266

def create_index
  @index = Index.new(@project)
end

#create_search_dataObject



355
356
357
358
359
360
# File 'lib/almirah/project.rb', line 355

def create_search_data
  db = SpecificationsDb.new @project_data.specifications
  data_path = "#{@configuration.project_root_directory}/build/data"
  FileUtils.mkdir_p(data_path)
  db.save(data_path)
end


179
180
181
182
183
184
185
186
187
# File 'lib/almirah/project.rb', line 179

def link_all_decisions
  @project_data.decisions.each do |d|
    @project_data.specifications.each do |s|
      next unless d.up_link_docs.key?(s.id.to_s)

      DocLinker.link_decision_to_spec(d, s)
    end
  end
end

rubocop:disable Metrics/MethodLength



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/almirah/project.rb', line 163

def link_all_protocols # rubocop:disable Metrics/MethodLength
  @project_data.protocols.each do |p|
    @project_data.specifications.each do |s|
      if p.up_link_docs.key?(s.id.to_s)
        DocLinker.link_protocol_to_spec(p, s)
        @project_data.covered_specifications_dictionary[s.id.to_s] = s
      end
    end
  end
  # create coverage documents
  @project_data.covered_specifications_dictionary.each do |_key, value|
    doc = DocFabric.create_coverage_matrix(value)
    @project_data.coverage_matrices.append doc
  end
end


189
190
191
192
193
194
195
196
197
# File 'lib/almirah/project.rb', line 189

def link_all_source_files
  return unless DocLinker.link_all_source_files(@project_data)

  # create implementation documents
  @project_data.implemented_specifications_dictionary.each do |_key, value|
    doc = DocFabric.create_implementation_document(value)
    @project_data.implementation_matrices.append doc
  end
end

rubocop:disable Metrics/MethodLength,Metrics/AbcSize



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/almirah/project.rb', line 145

def link_all_specifications # rubocop:disable Metrics/MethodLength,Metrics/AbcSize
  comb_list = @project_data.specifications.combination(2)
  comb_list.each do |c|
    link_two_specifications(c[0], c[1])
    # puts "Link: #{c[0].id} - #{c[1].id}"
  end
  # separatelly create design inputs treceability
  @configuration.get_design_inputs.each do |i|
    next unless @project_data.specifications_dictionary.key? i.to_s.downcase

    document = @project_data.specifications_dictionary[i.to_s.downcase]
    if document
      doc = DocFabric.create_traceability_document(document, nil)
      @project_data.traceability_matrices.append doc
    end
  end
end

rubocop:disable Metrics/AbcSize,Metrics/CyclomaticComplexity,Metrics/MethodLength,Metrics/PerceivedComplexity



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/almirah/project.rb', line 229

def link_two_specifications(doc_a, doc_b) # rubocop:disable Metrics/AbcSize,Metrics/CyclomaticComplexity,Metrics/MethodLength,Metrics/PerceivedComplexity
  if doc_b.up_link_docs.key?(doc_a.id.to_s)
    top_document = doc_a
    bottom_document = doc_b
  elsif doc_a.up_link_docs.key?(doc_b.id.to_s)
    top_document = doc_b
    bottom_document = doc_a
  else
    return # no links
  end
  # puts "Link: #{doc_a.id} - #{doc_b.id}"
  bottom_document.controlled_items.each do |item|
    next unless item.up_link_ids

    item.up_link_ids.each do |up_lnk|
      if top_document.dictionary.key?(up_lnk.to_s)

        top_item = top_document.dictionary[up_lnk.to_s]

        unless top_item.down_links
          top_item.down_links = []
          top_document.items_with_downlinks_number += 1 # for statistics
        end
        top_item.down_links.append(item)
      elsif tmp = /^([a-zA-Z]+)-\d+/.match(up_lnk)
        # check if there is a non existing link with the right doc_id
        if tmp[1].downcase == top_document.id.downcase
          bottom_document.wrong_links_hash[up_lnk] = item
        end # SRS
      end
    end
  end
  # create treceability document
  doc = DocFabric.create_traceability_document(top_document, bottom_document)
  @project_data.traceability_matrices.append doc
end

#parse_all_protocolsObject



100
101
102
103
104
105
106
# File 'lib/almirah/project.rb', line 100

def parse_all_protocols
  path = @configuration.project_root_directory
  Dir.glob("#{path}/tests/protocols/**/*.md").each do |f|
    doc = DocFabric.create_protocol(f)
    @project_data.protocols.append(doc)
  end
end

#parse_all_source_filesObject



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/almirah/project.rb', line 108

def parse_all_source_files
  @configuration.get_repositories.each do |repos|
    # puts "Processing repository: #{repos['name']}, #{repos['path']}"
    next unless repos['path'] && Dir.exist?(repos['path'])

    file_path = repos['path']
    Dir.glob("#{repos['path']}/**/*.*").each do |f|
      next unless File.file?(f) && f.end_with?('.c', '.cpp', '.h', '.hpp', '.py', '.java', '.rb', '.js', '.ts', '.go',
                                               '.rs')

      doc = DocFabric.create_source_file(file_path, f, repos['name'])
      # puts "Source file: #{doc.id}"
      @project_data.source_files.append(doc)
    end
  end
end

#parse_all_specificationsObject



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/almirah/project.rb', line 86

def parse_all_specifications
  path = @configuration.project_root_directory
  # do a lasy pass first to get the list of documents id
  Dir.glob("#{path}/specifications/**/*.md").each do |f|
    DocFabric.add_lazy_doc_id(f)
  end
  # parse documents in the second pass
  Dir.glob("#{path}/specifications/**/*.md").each do |f| # rubocop:disable Style/CombinableLoops
    doc = DocFabric.create_specification(f)
    @project_data.specifications.append(doc)
    @project_data.specifications_dictionary[doc.id.to_s.downcase] = doc
  end
end

#parse_decisionsObject



125
126
127
128
129
130
131
132
133
134
135
# File 'lib/almirah/project.rb', line 125

def parse_decisions
  path = @configuration.project_root_directory
  decisions_root = "#{path}/decisions"
  Dir.glob("#{decisions_root}/**/*.md").each do |f|
    doc = DocFabric.create_decision(f)
    rel_dir = File.dirname(f.sub("#{decisions_root}/", ''))
    doc.html_rel_path = rel_dir == '.' ? "#{doc.id}.html" : "#{rel_dir}/#{doc.id}.html"
    @project_data.decisions.append(doc)
  end
  BaseDocument.show_decisions_link = @project_data.decisions.any?
end

#parse_test_run(test_run) ⇒ Object



137
138
139
140
141
142
143
# File 'lib/almirah/project.rb', line 137

def parse_test_run(test_run)
  path = @configuration.project_root_directory
  Dir.glob("#{path}/tests/runs/#{test_run}/**/*.md").each do |f|
    doc = DocFabric.create_protocol(f)
    @project_data.protocols.append(doc)
  end
end

#render_all_decisionsObject

rubocop:disable Metrics/MethodLength,Metrics/AbcSize



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/almirah/project.rb', line 339

def render_all_decisions # rubocop:disable Metrics/MethodLength,Metrics/AbcSize
  return if @project_data.decisions.empty?

  build_decisions_root = "#{@configuration.project_root_directory}/build/decisions"
  @project_data.decisions.each do |doc|
    out_dir_rel = File.dirname(doc.html_rel_path)
    out_dir = out_dir_rel == '.' ? build_decisions_root : "#{build_decisions_root}/#{out_dir_rel}"
    FileUtils.mkdir_p(out_dir)
    depth = 1 + (out_dir_rel == '.' ? 0 : out_dir_rel.split('/').size)
    doc.root_prefix = '../' * depth
    doc.specifications_path = "./#{doc.root_prefix}specifications/"
    doc.to_console
    doc.to_html(NavigationPane.new(doc), "#{out_dir}/")
  end
end

#render_all_protocolsObject



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/almirah/project.rb', line 290

def render_all_protocols
  path = @configuration.project_root_directory

  FileUtils.mkdir_p("#{path}/build/tests/protocols")

  @project_data.protocols.each do |doc|
    img_src_dir = "#{path}/tests/protocols/#{doc.id}/img"
    img_dst_dir = "#{path}/build/tests/protocols/#{doc.id}/img"

    FileUtils.mkdir_p(img_dst_dir)

    FileUtils.copy_entry(img_src_dir, img_dst_dir) if File.directory?(img_src_dir)

    nav_pane = NavigationPane.new(doc)
    doc.to_html(nav_pane, "#{path}/build/tests/protocols/")
  end
end

#render_all_source_filesObject



308
309
310
311
312
313
314
315
316
317
# File 'lib/almirah/project.rb', line 308

def render_all_source_files
  path = @configuration.project_root_directory
  FileUtils.mkdir_p("#{path}/build/source_files")

  @project_data.source_files.each do |doc|
    doc.to_console

    doc.to_html("#{path}/build/source_files/")
  end
end

#render_all_specifications(spec_list) ⇒ Object

rubocop:disable Metrics/MethodLength



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/almirah/project.rb', line 270

def render_all_specifications(spec_list) # rubocop:disable Metrics/MethodLength
  path = @configuration.project_root_directory

  FileUtils.mkdir_p("#{path}/build/specifications")

  spec_list.each do |doc|
    doc.to_console

    img_src_dir = "#{path}/specifications/#{doc.id}/img"
    img_dst_dir = "#{path}/build/specifications/#{doc.id}/img"

    FileUtils.mkdir_p(img_dst_dir)

    FileUtils.copy_entry(img_src_dir, img_dst_dir) if File.directory?(img_src_dir)

    nav_pane = NavigationPane.new(doc)
    doc.to_html(nav_pane, "#{path}/build/specifications/")
  end
end

#render_decisions_overviewObject



328
329
330
331
332
333
334
335
336
337
# File 'lib/almirah/project.rb', line 328

def render_decisions_overview
  return if @project_data.decisions.empty?

  path = @configuration.project_root_directory
  FileUtils.mkdir_p("#{path}/build/decisions")

  doc = DocFabric.create_decisions_overview(@project)
  doc.to_console
  doc.to_html("#{path}/build/decisions/")
end

#render_indexObject



319
320
321
322
323
324
325
326
# File 'lib/almirah/project.rb', line 319

def render_index
  path = @configuration.project_root_directory

  doc = @index
  doc.to_console

  doc.to_html("#{path}/build/")
end

#specifications_and_protocolsObject

rubocop:disable Metrics/MethodLength,Metrics/AbcSize



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/almirah/project.rb', line 40

def specifications_and_protocols # rubocop:disable Metrics/MethodLength,Metrics/AbcSize
  parse_all_specifications
  parse_all_protocols
  parse_all_source_files
  parse_decisions
  link_all_specifications
  link_all_protocols
  link_all_source_files
  link_all_decisions
  check_wrong_specification_referenced
  create_index
  render_all_specifications(@project_data.specifications)
  render_all_specifications(@project_data.traceability_matrices)
  render_all_specifications(@project_data.coverage_matrices)
  render_all_protocols
  render_all_source_files
  render_all_specifications(@project_data.implementation_matrices) # intentionally after source file rendering
  render_decisions_overview
  render_all_decisions
  render_index
  create_search_data
end

#specifications_and_results(test_run) ⇒ Object

rubocop:disable Metrics/MethodLength,Metrics/AbcSize



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/almirah/project.rb', line 63

def specifications_and_results(test_run) # rubocop:disable Metrics/MethodLength,Metrics/AbcSize
  parse_all_specifications
  parse_test_run test_run
  parse_all_source_files
  parse_decisions
  link_all_specifications
  link_all_protocols
  link_all_source_files
  link_all_decisions
  check_wrong_specification_referenced
  create_index
  render_all_specifications(@project_data.specifications)
  render_all_specifications(@project_data.traceability_matrices)
  render_all_specifications(@project_data.coverage_matrices)
  render_all_protocols
  render_all_source_files
  render_all_specifications(@project_data.implementation_matrices) # intentionally after source file rendering
  render_decisions_overview
  render_all_decisions
  render_index
  create_search_data
end