Class: ProjectData
- Inherits:
-
Object
- Object
- ProjectData
- Defined in:
- lib/almirah/project/project_data.rb
Instance Attribute Summary collapse
-
#coverage_matrices ⇒ Object
readonly
Returns the value of attribute coverage_matrices.
-
#covered_specifications_dictionary ⇒ Object
readonly
Returns the value of attribute covered_specifications_dictionary.
-
#decision_groups ⇒ Object
readonly
Returns the value of attribute decision_groups.
-
#decisions ⇒ Object
readonly
Returns the value of attribute decisions.
-
#implementation_matrices ⇒ Object
readonly
Returns the value of attribute implementation_matrices.
-
#implemented_specifications_dictionary ⇒ Object
readonly
Returns the value of attribute implemented_specifications_dictionary.
-
#link_registry ⇒ Object
readonly
Returns the value of attribute link_registry.
-
#protocols ⇒ Object
readonly
Returns the value of attribute protocols.
-
#source_files ⇒ Object
readonly
Returns the value of attribute source_files.
-
#specifications ⇒ Object
readonly
Returns the value of attribute specifications.
-
#specifications_dictionary ⇒ Object
readonly
Returns the value of attribute specifications_dictionary.
-
#traceability_matrices ⇒ Object
readonly
Returns the value of attribute traceability_matrices.
-
#work_items ⇒ Object
readonly
Returns the value of attribute work_items.
Instance Method Summary collapse
-
#initialize ⇒ ProjectData
constructor
A new instance of ProjectData.
Constructor Details
#initialize ⇒ ProjectData
Returns a new instance of ProjectData.
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/almirah/project/project_data.rb', line 8 def initialize @specifications = [] @protocols = [] @traceability_matrices = [] @coverage_matrices = [] @source_files = [] @implementation_matrices = [] @decisions = [] # Insertion-ordered list of single-key hashes { "<first-level folder>" => [Decision, ...] }, # grouping decision records by the planning folder they live in (see ADR-197). @decision_groups = [] # Every Scope-row WorkItem across all decision records, keyed by its canonical # "<record>.<step>.<activity>" id (see ADR-194), populated by link_work_items. @work_items = {} @specifications_dictionary = {} @covered_specifications_dictionary = {} @implemented_specifications_dictionary = {} @link_registry = LinkRegistry.new end |
Instance Attribute Details
#coverage_matrices ⇒ Object (readonly)
Returns the value of attribute coverage_matrices.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def coverage_matrices @coverage_matrices end |
#covered_specifications_dictionary ⇒ Object (readonly)
Returns the value of attribute covered_specifications_dictionary.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def covered_specifications_dictionary @covered_specifications_dictionary end |
#decision_groups ⇒ Object (readonly)
Returns the value of attribute decision_groups.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def decision_groups @decision_groups end |
#decisions ⇒ Object (readonly)
Returns the value of attribute decisions.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def decisions @decisions end |
#implementation_matrices ⇒ Object (readonly)
Returns the value of attribute implementation_matrices.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def implementation_matrices @implementation_matrices end |
#implemented_specifications_dictionary ⇒ Object (readonly)
Returns the value of attribute implemented_specifications_dictionary.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def implemented_specifications_dictionary @implemented_specifications_dictionary end |
#link_registry ⇒ Object (readonly)
Returns the value of attribute link_registry.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def link_registry @link_registry end |
#protocols ⇒ Object (readonly)
Returns the value of attribute protocols.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def protocols @protocols end |
#source_files ⇒ Object (readonly)
Returns the value of attribute source_files.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def source_files @source_files end |
#specifications ⇒ Object (readonly)
Returns the value of attribute specifications.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def specifications @specifications end |
#specifications_dictionary ⇒ Object (readonly)
Returns the value of attribute specifications_dictionary.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def specifications_dictionary @specifications_dictionary end |
#traceability_matrices ⇒ Object (readonly)
Returns the value of attribute traceability_matrices.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def traceability_matrices @traceability_matrices end |
#work_items ⇒ Object (readonly)
Returns the value of attribute work_items.
4 5 6 |
# File 'lib/almirah/project/project_data.rb', line 4 def work_items @work_items end |